searchNodes=[{"doc":"Shared data structures and utilities for the Lexical Language Server. If you're building a plugin, You're probably going to want to look at the documentation for core data structures like Lexical.Project - The lexical project structure Lexical.Document - A text document, given to you by the language server Lexical.Document.Position - A position inside a document Lexical.Document.Range - A range of text inside a document","ref":"Lexical.html","title":"Lexical","type":"module"},{"doc":"A string representation of a path on the filesystem","ref":"Lexical.html#t:path/0","title":"Lexical.path/0","type":"type"},{"doc":"A string representation of a uri","ref":"Lexical.html#t:uri/0","title":"Lexical.uri/0","type":"type"},{"doc":"A protocol that details conversions to and from Language Server idioms The Language Server specification defines a couple of data structures that differ wildly from similar data structures and concepts in Elixir. Among these are positions and ranges. Elixir's parser thinks in terms of UTF-8 graphemes and uses one-based line and column numbers, while the language server speaks in UTF-16 code unit offsets and uses zero-based line and character (a misnomer, in reality this is a UTF-16 code unit) offsets. If not handled centrally, this leads to a profusion of conversion code throughout the language server codebase. That's where this protocol comes in. Using this protocol allows us to define native Lexical.Document.Position and Lexical.Document.Range structs and have them automatically convert into their Language Server counterparts, centralizing the conversion logic in a single pace. Note: You do not need to do conversions manually, If you define a new type, it is sufficient to implement this protocol for your new type","ref":"Lexical.Convertible.html","title":"Lexical.Convertible","type":"protocol"},{"doc":"Converts the native representation to a LSP compatible struct","ref":"Lexical.Convertible.html#to_lsp/1","title":"Lexical.Convertible.to_lsp/1","type":"function"},{"doc":"Converts the structure to a native implementation","ref":"Lexical.Convertible.html#to_native/2","title":"Lexical.Convertible.to_native/2","type":"function"},{"doc":"A Language server term","ref":"Lexical.Convertible.html#t:lsp/0","title":"Lexical.Convertible.lsp/0","type":"type"},{"doc":"The result of converting a native term into a lsp term","ref":"Lexical.Convertible.html#t:lsp_response/0","title":"Lexical.Convertible.lsp_response/0","type":"type"},{"doc":"A native term that contains ranges, positions or both","ref":"Lexical.Convertible.html#t:native/0","title":"Lexical.Convertible.native/0","type":"type"},{"doc":"The result of converting a lsp term into a native term","ref":"Lexical.Convertible.html#t:native_response/0","title":"Lexical.Convertible.native_response/0","type":"type"},{"doc":"Any type that can be converted using this protocol","ref":"Lexical.Convertible.html#t:t/0","title":"Lexical.Convertible.t/0","type":"type"},{"doc":"A representation of a LSP text document A document is the fundamental data structure of the Lexical language server. All language server documents are represented and backed by documents, which provide functionality for fetching lines, applying changes, and tracking versions.","ref":"Lexical.Document.html","title":"Lexical.Document","type":"module"},{"doc":"Get the Lexical&gt;Document.Line at the given index using fetch semantics. This function is of limited utility, you probably want fetch_text_at/2 instead.","ref":"Lexical.Document.html#fetch_line_at/2","title":"Lexical.Document.fetch_line_at/2","type":"function"},{"doc":"Get the text at the given line using fetch semantics Returns {:ok, text} if the line exists, and :error if it doesn't. The line text is returned without the line end character(s). This is a constant time operation.","ref":"Lexical.Document.html#fetch_text_at/2","title":"Lexical.Document.fetch_text_at/2","type":"function"},{"doc":"Returns a fragment defined by the from and to arguments Builds a string that represents the text of the document from the two positions given. The from position, defaults to :beginning meaning the start of the document. Positions can be a Document.Position.t or anything that will convert to a position using Lexical.Convertible.to_native/2 .","ref":"Lexical.Document.html#fragment/3","title":"Lexical.Document.fragment/3","type":"function"},{"doc":"Marks the document file as clean This function is mainly used internally by lexical","ref":"Lexical.Document.html#mark_clean/1","title":"Lexical.Document.mark_clean/1","type":"function"},{"doc":"Marks the document file as dirty This function is mainly used internally by lexical","ref":"Lexical.Document.html#mark_dirty/1","title":"Lexical.Document.mark_dirty/1","type":"function"},{"doc":"Creates a new document from a uri or path, the source code as a binary and the vewrsion.","ref":"Lexical.Document.html#new/3","title":"Lexical.Document.new/3","type":"function"},{"doc":"Returns the number of lines in the document This is a constant time operation.","ref":"Lexical.Document.html#size/1","title":"Lexical.Document.size/1","type":"function"},{"doc":"Converts a document to a string This function converts the given document back into a string, with line endings preserved.","ref":"Lexical.Document.html#to_string/1","title":"Lexical.Document.to_string/1","type":"function"},{"doc":"","ref":"Lexical.Document.html#t:change_application_error/0","title":"Lexical.Document.change_application_error/0","type":"type"},{"doc":"","ref":"Lexical.Document.html#t:fragment_position/0","title":"Lexical.Document.fragment_position/0","type":"type"},{"doc":"","ref":"Lexical.Document.html#t:t/0","title":"Lexical.Document.t/0","type":"type"},{"doc":"","ref":"Lexical.Document.html#t:version/0","title":"Lexical.Document.version/0","type":"type"},{"doc":"A Lexical.Document.Container for text edits. This struct is helpful if you need to express one or several text edits in an LSP response. It will convert cleanly into either a single TextEdit or a list of TextEdit s depending on whether you passed a single edit or a list of edits. Using this struct allows efficient conversions at the language server border, as the document doesn't have to be looked up (and possibly read off the filesystem) by the language server.","ref":"Lexical.Document.Changes.html","title":"Lexical.Document.Changes","type":"module"},{"doc":"Creates a new Changes struct given a document and edits.","ref":"Lexical.Document.Changes.html#new/2","title":"Lexical.Document.Changes.new/2","type":"function"},{"doc":"","ref":"Lexical.Document.Changes.html#t:edits/0","title":"Lexical.Document.Changes.edits/0","type":"type"},{"doc":"","ref":"Lexical.Document.Changes.html#t:t/0","title":"Lexical.Document.Changes.t/0","type":"type"},{"doc":"A protocol used to find relevant documents in structs When converting positions from lsp formats to native and vice versa, you need the line of text from the relevant document. However, due to the nature of the protocol structs, there isn't a single place where the document (or a reference) to the document sits. This protocol allows generic access to the relevant document regardless of the structure. Note: This protocol only needs to be implemented for structs that don't have a document field, or don't have a text_document field with a uri sub-field. The following structs would not need an implementation: % MyStruct { document : % Lexical.Document { } } % MyStruct { text_document : %{ uri : &quot;file:///path/to/document.ex&quot; } }","ref":"Lexical.Document.Container.html","title":"Lexical.Document.Container","type":"protocol"},{"doc":"","ref":"Lexical.Document.Container.html#context_document/2","title":"Lexical.Document.Container.context_document/2","type":"function"},{"doc":"","ref":"Lexical.Document.Container.html#t:maybe_context_document/0","title":"Lexical.Document.Container.maybe_context_document/0","type":"type"},{"doc":"","ref":"Lexical.Document.Container.html#t:t/0","title":"Lexical.Document.Container.t/0","type":"type"},{"doc":"A change to a document A Lexical.Document.Edit represents a single change to a document. It contains the new text and a range where the edit applies.","ref":"Lexical.Document.Edit.html","title":"Lexical.Document.Edit","type":"module"},{"doc":"Creates a new edit that replaces all text in the document","ref":"Lexical.Document.Edit.html#new/1","title":"Lexical.Document.Edit.new/1","type":"function"},{"doc":"Creates a new edit that replaces text in the given range","ref":"Lexical.Document.Edit.html#new/2","title":"Lexical.Document.Edit.new/2","type":"function"},{"doc":"","ref":"Lexical.Document.Edit.html#t:t/0","title":"Lexical.Document.Edit.t/0","type":"type"},{"doc":"A record representing a line of text in a document A line contains the following keys: text : The actual text of the line, without the line ending ending : The end of line character(s) can be &quot;\\n&quot; , &quot;\\r&quot; or &quot;\\r\\n&quot; . The original line ending is preserved line_number : A zero-based line number ascii? : A boolean representing if this line consists of only ascii text.","ref":"Lexical.Document.Line.html","title":"Lexical.Document.Line","type":"module"},{"doc":"Creates or matches a line of text","ref":"Lexical.Document.Line.html#line/1","title":"Lexical.Document.Line.line/1","type":"macro"},{"doc":"","ref":"Lexical.Document.Line.html#line/2","title":"Lexical.Document.Line.line/2","type":"macro"},{"doc":"","ref":"Lexical.Document.Line.html#t:t/0","title":"Lexical.Document.Line.t/0","type":"type"},{"doc":"A parser that parses a binary into Lexical.Document.Line records. The approach taken by the parser is to first go through the binary to find out where the lines break, what their endings are and if the line is ascii. As we go through the binary, we store this information, and when we're done, go back and split up the binary using binary_slice . This performs 3x faster than iterating through the binary and collecting IOlists that represent each line. I determines if a line is ascii (and what it really means is utf8 ascii) by checking to see if each byte is greater than 0 and less than 128. UTF-16 files won't be marked as ascii, which allows us to skip a lot of byte conversions later in the process.","ref":"Lexical.Document.LineParser.html","title":"Lexical.Document.LineParser","type":"module"},{"doc":"Parses the text into lines Parses the given text into lines, and uses starting_index as the first line's line number. Passing 0 as starting_index yields a zero-based collection, while passing 1 yields a 1-based collection.","ref":"Lexical.Document.LineParser.html#parse/2","title":"Lexical.Document.LineParser.parse/2","type":"function"},{"doc":"A hyper-optimized, line-based backing store for text documents","ref":"Lexical.Document.Lines.html","title":"Lexical.Document.Lines","type":"module"},{"doc":"Gets the current line with the given index using fetch semantics","ref":"Lexical.Document.Lines.html#fetch_line/2","title":"Lexical.Document.Lines.fetch_line/2","type":"function"},{"doc":"Create a new line store with the given text at the given starting index","ref":"Lexical.Document.Lines.html#new/2","title":"Lexical.Document.Lines.new/2","type":"function"},{"doc":"Returns the number of lines in the line store","ref":"Lexical.Document.Lines.html#size/1","title":"Lexical.Document.Lines.size/1","type":"function"},{"doc":"Turnss a line store into an iolist","ref":"Lexical.Document.Lines.html#to_iodata/1","title":"Lexical.Document.Lines.to_iodata/1","type":"function"},{"doc":"Turns a line store into a string","ref":"Lexical.Document.Lines.html#to_string/1","title":"Lexical.Document.Lines.to_string/1","type":"function"},{"doc":"","ref":"Lexical.Document.Lines.html#t:t/0","title":"Lexical.Document.Lines.t/0","type":"type"},{"doc":"A location in a document One of the fundamental LSP structures, this represents a subset of text in a document. The location is bounded by the given range, and the document can be given as a Lexical.Document struct, or a uri referencing the document","ref":"Lexical.Document.Location.html","title":"Lexical.Document.Location","type":"module"},{"doc":"","ref":"Lexical.Document.Location.html#new/2","title":"Lexical.Document.Location.new/2","type":"function"},{"doc":"Returns the location document's uri.","ref":"Lexical.Document.Location.html#uri/1","title":"Lexical.Document.Location.uri/1","type":"function"},{"doc":"","ref":"Lexical.Document.Location.html#t:t/0","title":"Lexical.Document.Location.t/0","type":"type"},{"doc":"A collection of functions dealing with converting filesystem paths to URIs and back","ref":"Lexical.Document.Path.html","title":"Lexical.Document.Path","type":"module"},{"doc":"","ref":"Lexical.Document.Path.html#absolute_from_uri/1","title":"Lexical.Document.Path.absolute_from_uri/1","type":"function"},{"doc":"Given a uri or a path, either return the path unmodified or converts the uri to a path","ref":"Lexical.Document.Path.html#ensure_path/1","title":"Lexical.Document.Path.ensure_path/1","type":"function"},{"doc":"Given a uri or a path, either return the uri unmodified or converts the path to a uri","ref":"Lexical.Document.Path.html#ensure_uri/1","title":"Lexical.Document.Path.ensure_uri/1","type":"function"},{"doc":"Returns path from URI in a way that handles windows file:///c%3A/... URLs correctly","ref":"Lexical.Document.Path.html#from_uri/1","title":"Lexical.Document.Path.from_uri/1","type":"function"},{"doc":"Converts a path into a URI","ref":"Lexical.Document.Path.html#to_uri/1","title":"Lexical.Document.Path.to_uri/1","type":"function"},{"doc":"","ref":"Lexical.Document.Path.html#t:uri_or_path/0","title":"Lexical.Document.Path.uri_or_path/0","type":"type"},{"doc":"A position inside of a document This struct represents a cursor position inside a document, using one-based line and character numbers. It's important to note that the position starts before the character given, so positions are inclusive of the given character. Given the following line of text: &quot;Hello there, welcome to lexical&quot; the position: %Lexical.Document.Position{line: 1, character: 1} starts before the &quot;H&quot; in &quot;Hello&quot;","ref":"Lexical.Document.Position.html","title":"Lexical.Document.Position","type":"module"},{"doc":"","ref":"Lexical.Document.Position.html#new/3","title":"Lexical.Document.Position.new/3","type":"function"},{"doc":"","ref":"Lexical.Document.Position.html#t:character/0","title":"Lexical.Document.Position.character/0","type":"type"},{"doc":"","ref":"Lexical.Document.Position.html#t:line/0","title":"Lexical.Document.Position.line/0","type":"type"},{"doc":"","ref":"Lexical.Document.Position.html#t:line_container/0","title":"Lexical.Document.Position.line_container/0","type":"type"},{"doc":"","ref":"Lexical.Document.Position.html#t:t/0","title":"Lexical.Document.Position.t/0","type":"type"},{"doc":"A range in a document Note that ranges represent a cursor position, and so are inclusive of lines, but exclusive of the end position. Note: To select an entire line, construct a range that runs from the first character on the line to the first character on the next line. whole_line = Range . new ( Position . new ( doc , 1 , 1 ) , Position . new ( doc , 2 , 1 ) )","ref":"Lexical.Document.Range.html","title":"Lexical.Document.Range","type":"module"},{"doc":"Returns whether the range contains the given position.","ref":"Lexical.Document.Range.html#contains?/2","title":"Lexical.Document.Range.contains?/2","type":"function"},{"doc":"Builds a new range.","ref":"Lexical.Document.Range.html#new/2","title":"Lexical.Document.Range.new/2","type":"function"},{"doc":"","ref":"Lexical.Document.Range.html#t:t/0","title":"Lexical.Document.Range.t/0","type":"type"},{"doc":"Backing store for source file documents.","ref":"Lexical.Document.Store.html","title":"Lexical.Document.Store","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Lexical.Document.Store.html#child_spec/1","title":"Lexical.Document.Store.child_spec/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#close/1","title":"Lexical.Document.Store.close/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#entropy/0","title":"Lexical.Document.Store.entropy/0","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#fetch/1","title":"Lexical.Document.Store.fetch/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#fetch/2","title":"Lexical.Document.Store.fetch/2","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#get_and_update/2","title":"Lexical.Document.Store.get_and_update/2","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#name/0","title":"Lexical.Document.Store.name/0","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#open/3","title":"Lexical.Document.Store.open/3","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#open?/1","title":"Lexical.Document.Store.open?/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#open_temporary/2","title":"Lexical.Document.Store.open_temporary/2","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#save/1","title":"Lexical.Document.Store.save/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#set_entropy/1","title":"Lexical.Document.Store.set_entropy/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#start_link/1","title":"Lexical.Document.Store.start_link/1","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#update/2","title":"Lexical.Document.Store.update/2","type":"function"},{"doc":"","ref":"Lexical.Document.Store.html#t:derivation/0","title":"Lexical.Document.Store.derivation/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:derivation_fun/0","title":"Lexical.Document.Store.derivation_fun/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:derivation_key/0","title":"Lexical.Document.Store.derivation_key/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:derivations/0","title":"Lexical.Document.Store.derivations/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:derived_value/0","title":"Lexical.Document.Store.derived_value/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:start_opt/0","title":"Lexical.Document.Store.start_opt/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:start_opts/0","title":"Lexical.Document.Store.start_opts/0","type":"type"},{"doc":"","ref":"Lexical.Document.Store.html#t:updater/0","title":"Lexical.Document.Store.updater/0","type":"type"},{"doc":"A collection of formatting functions","ref":"Lexical.Formats.html","title":"Lexical.Formats","type":"module"},{"doc":"","ref":"Lexical.Formats.html#mfa/3","title":"Lexical.Formats.mfa/3","type":"function"},{"doc":"Formats a name of a module Both elixir and erlang modules will format like they appear in elixir source code. Format . format ( MyModule ) &quot;MyModule&quot; Formats . module ( Somewhat.Nested.Module ) &quot;Somewhat.Nested.Module&quot; Format . format ( :erlang_module ) &quot;:erlang_module&quot;","ref":"Lexical.Formats.html#module/1","title":"Lexical.Formats.module/1","type":"function"},{"doc":"","ref":"Lexical.Formats.html#plural/3","title":"Lexical.Formats.plural/3","type":"function"},{"doc":"Formats an elapsed time to either seconds or milliseconds Examples: Format . seconds ( 500 , unit : :millisecond ) &quot;0.5 seconds&quot; Format . format ( 1500 , unit : :millisecond ) &quot;1.4 seconds&quot; Format . format ( 1500 ) &quot;15 ms&quot;","ref":"Lexical.Formats.html#time/2","title":"Lexical.Formats.time/2","type":"function"},{"doc":"","ref":"Lexical.Formats.html#t:time_opt/0","title":"Lexical.Formats.time_opt/0","type":"type"},{"doc":"","ref":"Lexical.Formats.html#t:time_opts/0","title":"Lexical.Formats.time_opts/0","type":"type"},{"doc":"","ref":"Lexical.Formats.html#t:unit/0","title":"Lexical.Formats.unit/0","type":"type"},{"doc":"Utilities related to mathematical operations","ref":"Lexical.Math.html","title":"Lexical.Math","type":"module"},{"doc":"Clamp the number between min_number and max_number If the first argument is less than min_number , then min_number is returned. If the number given in the first argument is greater than max_number then max_number is returned. Otherwise, the first argument is returned.","ref":"Lexical.Math.html#clamp/3","title":"Lexical.Math.clamp/3","type":"function"},{"doc":"A simple cache with a timeout that lives in the process dictionary","ref":"Lexical.ProcessCache.html","title":"Lexical.ProcessCache","type":"module"},{"doc":"","ref":"Lexical.ProcessCache.html#clear_keys/0","title":"Lexical.ProcessCache.clear_keys/0","type":"function"},{"doc":"Retrieves a value from the cache If the value is not found, the default is returned","ref":"Lexical.ProcessCache.html#fetch/1","title":"Lexical.ProcessCache.fetch/1","type":"function"},{"doc":"Retrieves a value from the cache If the value is not found, the default is returned","ref":"Lexical.ProcessCache.html#get/2","title":"Lexical.ProcessCache.get/2","type":"function"},{"doc":"Retrieves and optionally sets a value in the cache. Trans looks up a value in the cache under key. If that value isn't found, the compute_fn is then executed, and its return value is set in the cache. The cached value will live in the cache for timeout milliseconds","ref":"Lexical.ProcessCache.html#trans/3","title":"Lexical.ProcessCache.trans/3","type":"function"},{"doc":"","ref":"Lexical.ProcessCache.html#with_cleanup/1","title":"Lexical.ProcessCache.with_cleanup/1","type":"macro"},{"doc":"","ref":"Lexical.ProcessCache.html#t:fetch_result/0","title":"Lexical.ProcessCache.fetch_result/0","type":"type"},{"doc":"","ref":"Lexical.ProcessCache.html#t:key/0","title":"Lexical.ProcessCache.key/0","type":"type"},{"doc":"The representation of the current state of an elixir project. This struct contains all the information required to build a project and interrogate its configuration, as well as business logic for how to change its attributes.","ref":"Lexical.Project.html","title":"Lexical.Project","type":"module"},{"doc":"Retrieves the name of the project as an atom","ref":"Lexical.Project.html#atom_name/1","title":"Lexical.Project.atom_name/1","type":"function"},{"doc":"Returns the full path to the directory where lexical puts build artifacts","ref":"Lexical.Project.html#build_path/1","title":"Lexical.Project.build_path/1","type":"function"},{"doc":"","ref":"Lexical.Project.html#change_environment_variables/2","title":"Lexical.Project.change_environment_variables/2","type":"function"},{"doc":"Returns the the name definied in the project/0 of mix.exs file","ref":"Lexical.Project.html#display_name/1","title":"Lexical.Project.display_name/1","type":"function"},{"doc":"Creates and initializes lexical's workspace directory if it doesn't already exist","ref":"Lexical.Project.html#ensure_workspace/1","title":"Lexical.Project.ensure_workspace/1","type":"function"},{"doc":"","ref":"Lexical.Project.html#entropy/1","title":"Lexical.Project.entropy/1","type":"function"},{"doc":"Returns the full path to the project's mix.exs file","ref":"Lexical.Project.html#mix_exs_path/1","title":"Lexical.Project.mix_exs_path/1","type":"function"},{"doc":"Retrieves the name of the project","ref":"Lexical.Project.html#name/1","title":"Lexical.Project.name/1","type":"function"},{"doc":"","ref":"Lexical.Project.html#new/1","title":"Lexical.Project.new/1","type":"function"},{"doc":"The project node's name","ref":"Lexical.Project.html#node_name/1","title":"Lexical.Project.node_name/1","type":"function"},{"doc":"","ref":"Lexical.Project.html#project_path/1","title":"Lexical.Project.project_path/1","type":"function"},{"doc":"Returns the full path of the project's root directory","ref":"Lexical.Project.html#root_path/1","title":"Lexical.Project.root_path/1","type":"function"},{"doc":"","ref":"Lexical.Project.html#set_env_vars/2","title":"Lexical.Project.set_env_vars/2","type":"function"},{"doc":"","ref":"Lexical.Project.html#set_project_module/2","title":"Lexical.Project.set_project_module/2","type":"function"},{"doc":"Returns the full path to the project's lexical workspace directory Lexical maintains a workspace directory in project it konws about, and places various artifacts there. This function returns the full path to that directory","ref":"Lexical.Project.html#workspace_path/1","title":"Lexical.Project.workspace_path/1","type":"function"},{"doc":"Returns the full path to a file in lexical's workspace directory","ref":"Lexical.Project.html#workspace_path/2","title":"Lexical.Project.workspace_path/2","type":"function"},{"doc":"","ref":"Lexical.Project.html#t:error_with_message/0","title":"Lexical.Project.error_with_message/0","type":"type"},{"doc":"","ref":"Lexical.Project.html#t:message/0","title":"Lexical.Project.message/0","type":"type"},{"doc":"","ref":"Lexical.Project.html#t:restart_notification/0","title":"Lexical.Project.restart_notification/0","type":"type"},{"doc":"","ref":"Lexical.Project.html#t:t/0","title":"Lexical.Project.t/0","type":"type"},{"doc":"Allows structs to easily adopt the Access behaviour.","ref":"Lexical.StructAccess.html","title":"Lexical.StructAccess","type":"module"},{"doc":"","ref":"Lexical.Text.html","title":"Lexical.Text","type":"module"},{"doc":"","ref":"Lexical.Text.html#count_leading_spaces/1","title":"Lexical.Text.count_leading_spaces/1","type":"function"},{"doc":"","ref":"Lexical.Text.html#count_leading_spaces/2","title":"Lexical.Text.count_leading_spaces/2","type":"function"},{"doc":"This package contains some of the core data structures used in the Lexical Language server, and for building Lexical Plugins.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"If you're building a plugin, this package should be included when you add lexical_plugin to your deps. If, for some reason, you want to include it manually, do the following: def deps do [ { :lexical_shared , &quot;~&gt; 0.1.0&quot; , optional : true } ] end Complete documenation here: https://hexdocs.pm/lexical_shared .","ref":"readme.html#installation","title":"Overview - Installation","type":"extras"}]